package com.fs.his.service;

import java.util.List;

import com.fs.common.core.domain.R;
import com.fs.his.domain.FsPackageFavorite;

/**
 * 疗法收藏Service接口
 *
 * @author fs
 * @date 2024-08-24
 */
public interface IFsPackageFavoriteService
{
    /**
     * 查询疗法收藏
     *
     * @param favoriteId 疗法收藏主键
     * @return 疗法收藏
     */
    public FsPackageFavorite selectFsPackageFavoriteByFavoriteId(Long favoriteId);

    /**
     * 查询疗法收藏列表
     *
     * @param fsPackageFavorite 疗法收藏
     * @return 疗法收藏集合
     */
    public List<FsPackageFavorite> selectFsPackageFavoriteList(FsPackageFavorite fsPackageFavorite);

    /**
     * 新增疗法收藏
     *
     * @param fsPackageFavorite 疗法收藏
     * @return 结果
     */
    public int insertFsPackageFavorite(FsPackageFavorite fsPackageFavorite);

    /**
     * 修改疗法收藏
     *
     * @param fsPackageFavorite 疗法收藏
     * @return 结果
     */
    public int updateFsPackageFavorite(FsPackageFavorite fsPackageFavorite);

    /**
     * 批量删除疗法收藏
     *
     * @param favoriteIds 需要删除的疗法收藏主键集合
     * @return 结果
     */
    public int deleteFsPackageFavoriteByFavoriteIds(Long[] favoriteIds);

    /**
     * 删除疗法收藏信息
     *
     * @param favoriteId 疗法收藏主键
     * @return 结果
     */
    public int deleteFsPackageFavoriteByFavoriteId(Long favoriteId);

    R checkFavorite(Long packageId, long userId);

    int deleteFavorite(Long packageId, long l);
}
